@@ -1,8 +1,10 @@
 import os
 import uuid
+import time
 import asyncio
 import contextlib
 import threading
+
 import inflection
 import logging
 from typing import (
@@ -84,8 +86,16 @@ def spaced_name(n, ns) -> str:
     return f"{ns}/{n}"
 
 
-def trim_default_space(s):
-    return s.lstrip("default/")
+def trim_default_space(n):
+    return n.replace("default/", "")
+
+
+def simple_name(n):
+    return trim_default_space(n)
+
+
+def trim_gv(gvr):
+    return gvr.split("/")[-1]
 
 
 def gvr_from_body(b):
@@ -263,11 +273,25 @@ def put(path, src, target, transform=lambda x: x):
 
 
 def deep_get(d: dict, path: Union[str, Iterable], default=None) -> Any:
-    return reduce(lambda _d, key: _d.get(key, default) if isinstance(_d, dict) else default,
-                  path.split(".") if isinstance(path, str) else path, d)
+    """accepts paths in form root.'digi.dev/test'.control.power"""
+    if "'" in path or '"' in path:
+        path = path.replace('"', "'")
+        parsed = list()
+        for i, seg in enumerate(path.split("'")):
+            if seg == "":
+                continue
+            if i % 2 != 0:
+                parsed.append(seg)
+            else:
+                parsed += seg.strip(".").split(".")
+        path = parsed
+    else:
+        path = path.split(".") if isinstance(path, str) else path
+    return reduce(lambda _d, key: _d.get(key, default)
+    if isinstance(_d, dict) else default, path, d)
 
 
-def deep_set(d: dict, path: Union[str, Iterable], val: Any, create=False):
+def deep_set(d: dict, path: Union[str, Iterable], val: Any, create=True):
     if not isinstance(d, dict):
         return
     if isinstance(path, str):
@@ -311,13 +335,13 @@ def mount_size(mounts: dict, gvr_set: set = None,
         if gvr_set is not None and typ not in gvr_set:
             continue
 
-        if not all(cond(m) for m in models):
-            continue
-
-        if has_spec:
-            count += sum(1 if "spec" in m else 0 for m in models)
-        else:
-            count += len(models)
+        for _, m in models.items():
+            if not cond(m):
+                continue
+            if has_spec:
+                count += 1 if "spec" in m else 0
+            else:
+                count += 1
     return count
 
 
@@ -374,6 +398,9 @@ class Auri:
     def gvk(self) -> tuple:
         return self.group, self.version, self.kind
 
+    def auri(self):
+        return self.group, self.version, self.resource, self.name, self.namespace
+
     def __repr__(self):
         return self.__str__()
 
@@ -421,3 +448,33 @@ def parse_auri(s: str) -> Auri or None:
     if parsed is None:
         return None
     return Auri(**parsed)
+
+
+class Loader(threading.Thread):
+    def __init__(self, load_fn: callable, load_interval: float = 1):
+        threading.Thread.__init__(self)
+        self.load_fn = load_fn
+        self.load_interval = load_interval
+        self._stop_flag = threading.Event()
+
+    def run(self):
+        self._stop_flag.clear()
+        while not self._stop_flag.is_set():
+            self.load_fn()
+            time.sleep(self.load_interval)
+
+    def stop(self):
+        self._stop_flag.set()
+
+    def reset(self, load_interval: float = None) -> None:
+        if load_interval is not None:
+            self.load_interval = load_interval
+        self.stop()
+
+
+def name_from_auri(auri: tuple):
+    return auri[3]
+
+
+update = deep_set
+get = deep_get
